package com.kuyuntech.cofarcooking.device.sdk.devmode.core;

import com.kuyuntech.cofarcooking.device.sdk.constant.core.MotorDirections;
import com.kuyuntech.cofarcooking.device.sdk.constant.core.MotorHeightSpeed;
import com.kuyuntech.cofarcooking.device.sdk.constant.core.WorkModes;
import com.kuyuntech.cofarcooking.device.sdk.eventbus.core.DevInfo;
import com.kuyuntech.cofarcooking.device.sdk.util.core.CofarSDK;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.ToString;

import java.util.TimerTask;

@EqualsAndHashCode(callSuper = true)
@Data
@ToString
public class Brown extends BaseDevMode{

    private Long currentSec = 0l;

    private Thread thread;

    private boolean pasue = false;

    private boolean stop = false;

    public Brown(){

        this.setMode(WorkModes.BROWN);


        //时间
        this.setMinTime(0);
        this.setMaxTime(14 * 60);
        this.setDefaultTime(7 * 60);
        this.setTimeChange(true);

        //电机
        this.setDefaultMotorGear(0);
        this.setMaxMotorGear(0);
        this.setMaxMotorGear(0);
        this.setMotorGearChange(false);
        this.setMotorDirectionChange(false);

        //温度
        this.setDefaultTemp(130);
        this.setMinTemp(0);
        this.setMaxTemp(130);
    }

    @Override
    public void start() {
        currentSec = 0L;
        CofarSDK.startNative();
        this.stop = false;
    }


    @Override
    public void onCountDown(TimerTask timer) {

        if(pasue){
            CofarSDK.stop();
            return;
        }

        DevInfo devInfo = CofarSDK.devInfo();


        if (devInfo.getRemainTime() <= 0 && devInfo.getMode().isCountDown()) {
            CofarSDK.stop();
            timer.cancel();
            return;
        }


        if (stop) {
            CofarSDK.stop();
            timer.cancel();
            return;
        }

        devInfo.setRemainTime((short) (devInfo.getRemainTime() - 1));




        if(((currentSec / 5) % 7) == 1){
            CofarSDK.pauseNatvie();
        }

        if(((currentSec / 5) % 7) == 0){
            if(MotorDirections.REVERSE == CofarSDK.devInfo().getMotorDirection()){
                CofarSDK.cfgMotorDirectionNative(MotorDirections.FORWARD);
            }else{
                CofarSDK.cfgMotorDirectionNative(MotorDirections.REVERSE);
            }

            CofarSDK.resumeNavtive();
        }


        currentSec++;

    }

    @Override
    public void pause() {
        this.pasue = true;
        CofarSDK.pauseNatvie();
    }

    @Override
    public void resume() {
        this.pasue = false;
        CofarSDK.resumeNavtive();
    }

    @Override
    public void stop() {
        this.stop = true;
        CofarSDK.stopNative();
        super.stop();
    }


}
